# -*- coding: utf-8 -*-

from branca.element import MacroElement

from folium.elements import JSCSSMixin

from jinja2 import Template


class Terminator(JSCSSMixin, MacroElement):
    """
    Leaflet.Terminator is a simple plug-in to the Leaflet library to
    overlay day and night regions on maps.

    """
    _template = Template(u"""
        {% macro script(this, kwargs) %}
            L.terminator().addTo({{this._parent.get_name()}});
        {% endmacro %}
        """)

    default_js = [
        ('terminator',
         'https://unpkg.com/@joergdietrich/leaflet.terminator')
    ]

    def __init__(self):
        super(Terminator, self).__init__()
        self._name = 'Terminator'



from branca.element import MacroElement

from folium.elements import JSCSSMixin
from folium.utilities import parse_options

from jinja2 import Template


class Geocoder(JSCSSMixin, MacroElement):
    """A simple geocoder for Leaflet that by default uses OSM/Nominatim.

    Please respect the Nominatim usage policy:
    https://operations.osmfoundation.org/policies/nominatim/

    Parameters
    ----------
    collapsed: bool, default False
        If True, collapses the search box unless hovered/clicked.
    position: str, default 'topright'
        Choose from 'topleft', 'topright', 'bottomleft' or 'bottomright'.
    add_marker: bool, default True
        If True, adds a marker on the found location.

    For all options see https://github.com/perliedman/leaflet-control-geocoder

    """

    _template = Template(u"""
        {% macro script(this, kwargs) %}
            L.Control.geocoder(
                {{ this.options|tojson }}
            ).on('markgeocode', function(e) {
                {{ this._parent.get_name() }}.setView(e.geocode.center, 11);
            }).addTo({{ this._parent.get_name() }});

        {% endmacro %}
    """)

    default_js = [
        ('Control.Geocoder.js',
         'https://unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.js')
    ]
    default_css = [
        ('Control.Geocoder.css',
         'https://unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.css')
    ]

    def __init__(
            self,
            collapsed=False,
            position='topright',
            add_marker=True,
            **kwargs
    ):
        super(Geocoder, self).__init__()
        self._name = 'Geocoder'
        self.options = parse_options(
            collapsed=collapsed,
            position=position,
            defaultMarkGeocode=add_marker,
            **kwargs
        )



# -*- coding: utf-8 -*-

from branca.element import MacroElement

from folium.elements import JSCSSMixin
from folium.utilities import parse_options

from jinja2 import Template


class Fullscreen(JSCSSMixin, MacroElement):
    """
    Adds a fullscreen button to your map.

    Parameters
    ----------
    position : str
        change the position of the button can be:
        'topleft', 'topright', 'bottomright' or 'bottomleft'
        default: 'topleft'
    title : str
        change the title of the button,
        default: 'Full Screen'
    title_cancel : str
        change the title of the button when fullscreen is on,
        default: 'Exit Full Screen'
    force_separate_button : bool, default False
        force seperate button to detach from zoom buttons,

    See https://github.com/brunob/leaflet.fullscreen for more information.
    """
    _template = Template("""
        {% macro script(this, kwargs) %}
            L.control.fullscreen(
                {{ this.options|tojson }}
            ).addTo({{this._parent.get_name()}});
        {% endmacro %}
        """)  # noqa

    default_js = [
        ('Control.Fullscreen.js',
         'https://cdnjs.cloudflare.com/ajax/libs/leaflet.fullscreen/1.4.2/Control.FullScreen.min.js')
    ]
    default_css = [
        ('Control.FullScreen.css',
         'https://cdnjs.cloudflare.com/ajax/libs/leaflet.fullscreen/1.4.2/Control.FullScreen.min.css')
    ]

    def __init__(self, position='topleft', title='Full Screen',
                 title_cancel='Exit Full Screen', force_separate_button=False,
                 **kwargs):
        super(Fullscreen, self).__init__()
        self._name = 'Fullscreen'
        self.options = parse_options(
            position=position,
            title=title,
            title_cancel=title_cancel,
            force_separate_button=force_separate_button,
            **kwargs
        )
